#include <stdint.h>
#include <stdbool.h>

/* déclaration du type sudoku*/
typedef int sudoku[9][9];

/* Ces variables globales sont modifiées par lireAction() */
extern int entreeX, entreeY, entreeV; 

/** 
\fn bool estValideH(sudoku s,int x,int y,int n)
* \brief Vérifie s'il est valide de poser la valeur n en x et y en fonction des éléments déjà présents sur la ligne 
* 
* \param s le sudoku 
* \param x les coordonnées en x
* \param y les coordonnées en y 
* \param n la valeur que l'on veut poser  
* \return true si c'est valide, false sinon.  
*/
bool estValideH(sudoku s, int x, int y, int n);
/** 
\fn bool estValideV(sudoku s,int x,int y,int n)
* \brief Vérifie s'il est valide de poser la valeur n en x et y en fonction des éléments déjà présents sur la colonne
* 
* \param s le sudoku 
* \param x les coordonnées en x
* \param y les coordonnées en y 
* \param n la valeur que l'on veut poser  
* \return true si c'est valide, false
*/
bool estValideV(sudoku s,int x,int y, int n);
/** 
\fn bool estValideR(sudoku s,int x,int y, int n)
* \brief Vérifie s'il est valide de poser la valeur n en x et y en fonction des éléments déjà présents sur la région (3x3)
* 
* \param s le sudoku 
* \param x les coordonnées en x
* \param y les coordonnées en y 
* \param n la valeur que l'on veut poser  
* \return true si c'est valide, false sinon.  
*/
bool estValideR(sudoku s,int x,int y, int n);
/** 
\fn bool estValide(sudoku s,int x,int y,int n)
* \brief Vérifie s'il est valide de poser la valeur n en x et y en fonction de tous les éléments déjà présents
* appelle toutes les fonctions estValideH, estValideV, estValideR, 
* 
* \param s le sudoku 
* \param x les coordonnées en x
* \param y les coordonnées en y 
* \param n la valeur que l'on veut poser  
* \return true si c'est valide, false sinon.
*/
bool estValide(sudoku s,int x,int y,int n);

/** 
\fn int compterLibres(sudoku s)
* \brief calculer le nombre de cases encore vides sur la grille de sudoku 
* 
* \param s le sudoku 
* \param x les coordonnées en x
* \param y les coordonnées en y 
* \return le nombre de cases encore vides
*/
int compterLibres(sudoku s); 

/** 
\fn void afficherSudoku(sudoku s)
* \brief Affiche la grille actuelle du sudoku passé en paramètre
* 
* \param s le sudoku 
*/
void afficherSudoku(sudoku s);

/** 
\fn bool lireAction() 
* \brief LG : demande une action de résolution à l'utilisateur·rice 
* 
* Modifie les variables globales entreeX, entreeY, entreeV
* (coordonnées x et y et valeur) On utilise des variables globales car
* on ne sait pas "retourner un triplet", et un appel de fonction ne
* modifie pas les arguments entiers de la fonction. (Il nous faudrait
* la notion de pointeur, qui nest pour l'instant pas abordée dans le
* cours)
*   
* \return false si abandon ou erreur, true sinon.  
*/
bool lireAction();

/** BONUS**/
int resoudreSudoku(sudoku s);
